@@ -73,7 +73,7 @@ client = bybit.bybit(test=True, api_key="", api_secret="")
 # print(client.Wallet.Wallet_getBalance(coin="BTC").result())
 
 # # #Get exchange orders
-print(client.Wallet.Wallet_exchangeOrder().result())
+# print(client.Wallet.Wallet_exchangeOrder().result())
 # #
 # # #Get the Last Funding Rate
 # print(client.Funding.Funding_myLastFee(symbol="BTCUSD").result())
@@ -125,4 +125,5 @@ print(client.Wallet.Wallet_exchangeOrder().result())
 # print(client.Market.Market_openInterest(symbol="BTCUSDT", limit=2, period="5min").result())
 # print(client.Market.Market_accountRatio(symbol="BTCUSDT", limit=2, period="5min").result())
 # print(client.Market.Market_bigDeal(symbol="BTCUSDT", limit=2).result())
-
+# print(client.LinearWallet.LinearWallet_getRiskLimit().result())
+# print(client.LinearWallet.LinearWallet_setRiskLimit(symbol="BTCUSDT", side="Buy",risk_id="1").result())
\ No newline at end of file
